# $Id: /mirror/perl/Twitter-Shell/trunk/lib/Twitter/Shell/Base.pm 6476 2007-04-12T04:40:48.052531Z daisuke  $

package Twitter::Shell::Base;
use strict;
use warnings;
use base qw(Class::Accessor::Fast);

1;
